@@ -3,8 +3,13 @@
 
 test -f Makefile.am || cd "`dirname \"$0\"`"
 
+autopoint
+cp po/* po_messages
+cp po/* po_document
+rm -rf po
+
 # Create `aclocal.m4'.
-aclocal
+aclocal -I m4
 
 # Create `Makefile.in' from `Makefile.am', and symlink `install-sh',
 # `missing' and `mkinstalldirs' from /usr/share/automake.
